@@ -27,28 +27,28 @@ const CURRENT_EXE: &str = "tpnote";
 /// Tp-Note's configuration file filename.
 const CONFIG_FILENAME: &str = "tpnote.toml";
 
-/// Default value for command line option `--debug`.  Determines the maximum
+/// Default value for the command line option `--debug`.  Determines the maximum
 /// debug level events must have, to be logged.  If the command line option
 /// `--debug` is present, its value will be used instead.
 const ARG_DEFAULT_DEBUG: LevelFilter = LevelFilter::Error;
 
-/// Default value for command line flag `--edit` to disable file watcher,
+/// Default value for the command line flag `--edit` to disable file watcher,
 /// (Markdown)-renderer, html server and a web browser launcher set to `true`.
 const ARG_DEFAULT_EDITOR: bool = false;
 
-/// Default value for command line flag `--no-filename-sync` to disable
+/// Default value for the command line flag `--no-filename-sync` to disable
 /// the title to filename synchronisation mechanism permanently.
 /// If set to `true`, the corresponding command line flag is ignored.
 const ARG_DEFAULT_NO_FILENAME_SYNC: bool = false;
 
-/// Default value for command line flag `--popup`. If the command line flag
+/// Default value for the command line flag `--popup`. If the command line flag
 /// `--popup` or `POPUP` is `true`, all log events will also trigger the
 /// appearance of a popup alert window.  Note, that error level debug events
 /// will always pop up, regardless of `--popup` and `POPUP` (unless
 /// `--debug=off`).
 const ARG_DEFAULT_POPUP: bool = true;
 
-/// Default value for command line flag `--tty`. _Tp-Note_ tries different
+/// Default value for the command line flag `--tty`. _Tp-Note_ tries different
 /// heuristics to detect weather a graphic environment is available or not. For
 /// example, under Linux, the '`DISPLAY`' environment variable is evaluated. The
 /// '`--tty`' flag disables the automatic detection and sets _Tp-Note_ in
@@ -57,6 +57,12 @@ const ARG_DEFAULT_POPUP: bool = true;
 /// to `true` _Tp-Note_ starts in console mode permanently.
 const ARG_DEFAULT_TTY: bool = false;
 
+/// Default value for the command line flag `--add-header`. If unset,
+/// _Tp-Note_ exits of when it tries to open a text file without a YAML
+/// header. When this flag is set, the missing header is constructed by
+/// means of the text file's filename and creation date.
+const ARG_DEFAULT_ADD_HEADER: bool = true;
+
 /// Maximum length of a note's filename in bytes. If a filename template produces
 /// a longer string, it will be truncated.
 #[cfg(not(test))]
@@ -223,7 +229,7 @@ const TMPL_NEW_FILENAME: &str = "\
 /// fm_title }}`.
 /// When placed in YAML front matter, the filter `| json_encode` must be
 /// appended to each variable.
-const TMPL_COPY_CONTENT: &str = "\
+const TMPL_FROM_CLIPBOARD_YAML_CONTENT: &str = "\
 ---
 title:      {{ fm_title | default(value = path|trim_tag) | cut | json_encode }}
 subtitle:   {{ fm_subtitle | default(value = 'Note') | cut | json_encode }}
@@ -246,7 +252,7 @@ lang:       {{ fm_lang | default(value = get_env(name='LANG', default='')) | jso
 
 /// Default filename template used when the stdin or the clipboard contains a string and one of
 /// them has a valid YAML header.
-const TMPL_COPY_FILENAME: &str = "\
+const TMPL_FROM_CLIPBOARD_YAML_FILENAME: &str = "\
 {{ fm_sort_tag | default(value = now() | date(format='%Y%m%d-')) }}\
 {{ fm_title | sanit(alpha=true) }}\
 {% if fm_subtitle | default(value='') | sanit != '' %}--{% endif %}\
@@ -260,9 +266,7 @@ const TMPL_COPY_FILENAME: &str = "\
 /// hyperlink in Markdown or reStruncturedText format. See crate `parse-hyperlinks` for details.
 /// For example: `[<link-name>](<link-url> "link-title")`, can be accessed with the variables:
 /// `{{ clipboard | linkname }}`, `{{ clipboard | linktarget }}` and `{{ clipboard | linkttitle }}`.
-/// Trick: the expression `{% if clipboard != clipboard | heading %}` detects if the clipboard
-/// content has more than one line of text.
-const TMPL_CLIPBOARD_CONTENT: &str = "\
+const TMPL_FROM_CLIPBOARD_CONTENT: &str = "\
 {%- set lname = stdin ~ clipboard | linkname -%}
 {%- set ok_linkname = lname !=''\
     and not lname is starting_with(\"http\")\
@@ -288,16 +292,45 @@ lang:       {{ get_env(name='LANG', default='') | json_encode }}
 ";
 
 /// Default filename template used when the stdin ~ clipboard contains a string.
-const TMPL_CLIPBOARD_FILENAME: &str = "\
+const TMPL_FROM_CLIPBOARD_FILENAME: &str = "\
 {{ now() | date(format='%Y%m%d-') }}\
 {{ fm_title | sanit(alpha=true) }}\
 {% if fm_subtitle | default(value='') | sanit != '' %}--{% endif %}\
 {{ fm_subtitle | default(value='') | sanit  }}{{ extension_default | prepend_dot }}\
 ";
 
+/// Default template used, when the opened text file (with a known file
+/// extension) is missing a YAML front matter section. This template prepends
+/// such a section. The template inserts information extracted from the input
+/// filename and its creation date.
+const TMPL_FROM_TEXT_FILE_CONTENT: &str = "\
+---
+title:      {{ path | stem | split(pat='--') | first | cut | json_encode }}
+subtitle:   {{ path | stem | split(pat='--') | nth(n=1) | cut | json_encode }}
+author:     {{ username | json_encode }}
+date:       {{ path_file_date | date(format='%Y-%m-%d') | json_encode }}
+lang:       {{ get_env(name='LANG', default='') | json_encode }}
+orig_name:  {{ path | filename | json_encode }}
+---
+
+{{ path_file_text }}
+";
+
+/// Default filename template used when the input file (with a known
+/// file extension) is missing a YAML front matter section.
+/// The text file's sort-tag and file extension are preserved.
+const TMPL_FROM_TEXT_FILE_FILENAME: &str = "\
+{% if path | tag == '' %}{{ path_file_date | date(format='%Y%m%d-') }}\
+{% else %}{{ path | tag }}{% endif %}\
+{{ fm_title | sanit(alpha=true) }}\
+{% if fm_subtitle | default(value='') | sanit != '' %}--{% endif %}\
+{{ fm_subtitle | default(value='') | sanit  }}\
+{{ path | ext | prepend_dot }}\
+";
+
 /// Default template used when the command line <path> parameter points to an existing
 /// non-`.md`-file. Can be modified through editing the configuration file.
-const TMPL_ANNOTATE_CONTENT: &str = "\
+const TMPL_ANNOTATE_FILE_CONTENT: &str = "\
 ---
 title:      {{ path | trim_tag | json_encode }}
 {% if stdin ~ clipboard | linkname !='' and stdin ~ clipboard | heading == stdin ~ clipboard %}\
@@ -320,7 +353,7 @@ lang:       {{ get_env(name='LANG', default='') | json_encode }}
 
 /// Filename of a new note, that annotates an existing file on disk given in
 /// <path>.
-const TMPL_ANNOTATE_FILENAME: &str = "\
+const TMPL_ANNOTATE_FILE_FILENAME: &str = "\
 {{ path | tag }}{{ fm_title | sanit(alpha=true) }}\
 {% if fm_subtitle | default(value='') | sanit != '' %}--{% endif %}\
 {{ fm_subtitle | default(value='') | sanit }}{{ extension_default | prepend_dot }}\
@@ -710,6 +743,7 @@ pub struct ArgDefault {
     pub no_filename_sync: bool,
     pub popup: bool,
     pub tty: bool,
+    pub add_header: bool,
 }
 
 /// Configuration of filename parsing, deserialized from the
@@ -743,12 +777,14 @@ pub struct Tmpl {
     pub compulsory_header_field: String,
     pub new_content: String,
     pub new_filename: String,
-    pub copy_content: String,
-    pub copy_filename: String,
-    pub clipboard_content: String,
-    pub clipboard_filename: String,
-    pub annotate_content: String,
-    pub annotate_filename: String,
+    pub from_clipboard_yaml_content: String,
+    pub from_clipboard_yaml_filename: String,
+    pub from_clipboard_content: String,
+    pub from_clipboard_filename: String,
+    pub from_text_file_content: String,
+    pub from_text_file_filename: String,
+    pub annotate_file_content: String,
+    pub annotate_file_filename: String,
     pub sync_filename: String,
 }
 
@@ -813,6 +849,7 @@ impl ::std::default::Default for ArgDefault {
             no_filename_sync: ARG_DEFAULT_NO_FILENAME_SYNC,
             popup: ARG_DEFAULT_POPUP,
             tty: ARG_DEFAULT_TTY,
+            add_header: ARG_DEFAULT_ADD_HEADER,
         }
     }
 }
@@ -858,12 +895,14 @@ impl ::std::default::Default for Tmpl {
             compulsory_header_field: TMPL_COMPULSORY_HEADER_FIELD.to_string(),
             new_content: TMPL_NEW_CONTENT.to_string(),
             new_filename: TMPL_NEW_FILENAME.to_string(),
-            copy_content: TMPL_COPY_CONTENT.to_string(),
-            copy_filename: TMPL_COPY_FILENAME.to_string(),
-            clipboard_content: TMPL_CLIPBOARD_CONTENT.to_string(),
-            clipboard_filename: TMPL_CLIPBOARD_FILENAME.to_string(),
-            annotate_content: TMPL_ANNOTATE_CONTENT.to_string(),
-            annotate_filename: TMPL_ANNOTATE_FILENAME.to_string(),
+            from_clipboard_yaml_content: TMPL_FROM_CLIPBOARD_YAML_CONTENT.to_string(),
+            from_clipboard_yaml_filename: TMPL_FROM_CLIPBOARD_YAML_FILENAME.to_string(),
+            from_clipboard_content: TMPL_FROM_CLIPBOARD_CONTENT.to_string(),
+            from_clipboard_filename: TMPL_FROM_CLIPBOARD_FILENAME.to_string(),
+            from_text_file_content: TMPL_FROM_TEXT_FILE_CONTENT.to_string(),
+            from_text_file_filename: TMPL_FROM_TEXT_FILE_FILENAME.to_string(),
+            annotate_file_content: TMPL_ANNOTATE_FILE_CONTENT.to_string(),
+            annotate_file_filename: TMPL_ANNOTATE_FILE_FILENAME.to_string(),
             sync_filename: TMPL_SYNC_FILENAME.to_string(),
         }
     }
@@ -948,7 +987,7 @@ lazy_static! {
 /// Parse the configuration file if it exists. Otherwise write one with default values.
 #[cfg(not(test))]
 #[inline]
-fn config_load_path(config_path: &Path) -> Result<Cfg, FileError> {
+fn config_load(config_path: &Path) -> Result<Cfg, FileError> {
     if config_path.exists() {
         let config: Cfg = toml::from_str(&fs::read_to_string(config_path)?)?;
         // Check for obvious configuration errors.
@@ -984,21 +1023,35 @@ fn config_load_path(config_path: &Path) -> Result<Cfg, FileError> {
         // First check passed.
         Ok(config)
     } else {
-        fs::create_dir_all(config_path.parent().unwrap_or_else(|| Path::new("")))?;
-
-        let mut buffer = File::create(config_path)?;
-        buffer.write_all(toml::to_string_pretty(&Cfg::default())?.as_bytes())?;
-        Ok(Cfg::default())
+        let cfg = Cfg::default();
+        config_write(&cfg, config_path)?;
+        Ok(cfg)
     }
 }
 
 /// In unit tests we use the default configuration values.
 #[cfg(test)]
 #[inline]
-fn config_load_path(_config_path: &Path) -> Result<Cfg, FileError> {
+fn config_load(_config_path: &Path) -> Result<Cfg, FileError> {
     Ok(Cfg::default())
 }
 
+/// Writes the default configuration to `Path`.
+#[cfg(not(test))]
+fn config_write(config: &Cfg, config_path: &Path) -> Result<(), FileError> {
+    fs::create_dir_all(config_path.parent().unwrap_or_else(|| Path::new("")))?;
+
+    let mut buffer = File::create(config_path)?;
+    buffer.write_all(toml::to_string_pretty(config)?.as_bytes())?;
+    Ok(())
+}
+
+/// In unit tests we do not write anything.
+#[cfg(test)]
+fn config_write(_config: &Cfg, _config_path: &Path) -> Result<(), FileError> {
+    Ok(())
+}
+
 lazy_static! {
     /// Reads and parses the configuration file "tp-note.toml". An alternative
     /// filename (optionally with absolute path) can be given on the command line
@@ -1018,7 +1071,7 @@ lazy_static! {
             }
         };
 
-        config_load_path(config_path)
+        config_load(config_path)
             .unwrap_or_else(|e|{
                 // Remember that something went wrong.
                 let mut cfg_file_loading = CFG_FILE_LOADING.write().unwrap();
@@ -1053,6 +1106,8 @@ pub fn backup_config_file() -> Result<PathBuf, FileError> {
 
             fs::rename(&config_path.as_path(), &config_path_bak)?;
 
+            config_write(&Cfg::default(), config_path)?;
+
             Ok(config_path_bak)
         } else {
             Err(FileError::ConfigFileNotFound)
