@@ -17,6 +17,7 @@
 mod alert_service;
 mod config;
 mod content;
+mod context;
 mod error;
 mod file_editor;
 mod filename;
@@ -36,6 +37,8 @@ use crate::config::CFG;
 use crate::config::CFG_FILE_LOADING;
 use crate::config::CONFIG_PATH;
 #[cfg(feature = "read-clipboard")]
+use crate::error::NoteError;
+#[cfg(feature = "read-clipboard")]
 use crate::error::WorkflowError;
 use crate::logger::AppLogger;
 use crate::settings::ARGS;
@@ -80,7 +83,7 @@ const VERSION: Option<&'static str> = option_env!("CARGO_PKG_VERSION");
 ///    const MIN_CONFIG_FILE_VERSION: Option<&'static str> = None;
 ///    ```
 ///
-const MIN_CONFIG_FILE_VERSION: Option<&'static str> = Some("1.15.1");
+const MIN_CONFIG_FILE_VERSION: Option<&'static str> = VERSION;
 /// Authors.
 const AUTHOR: Option<&str> = option_env!("CARGO_PKG_AUTHORS");
 /// Copyright.
@@ -251,7 +254,12 @@ fn main() {
         && CFG.clipboard.read_enabled
         && CFG.clipboard.empty_enabled
         && !*RUNS_ON_CONSOLE)
-        || matches!(&res, Err(WorkflowError::InvalidClipboardYaml { .. }))
+        || matches!(
+            &res,
+            Err(WorkflowError::Note {
+                source: NoteError::InvalidClipboardYaml { .. },
+            })
+        )
     {
         if let Ok(ctx) = ClipboardProvider::new() {
             let mut ctx: ClipboardContext = ctx;
